@@ -28,23 +28,26 @@
 #define HAVE_LIMITS_H 1
 #define HAVE_SYS_FILE_H 1
 #define HAVE_SYS_IOCTL_H 1
-#define HAVE_SYS_SYSCALL_H 1
 #define HAVE_FCNTL_H 1
 #define HAVE_SYS_FCNTL_H 1
+#define HAVE_SYS_PARAM_H 1
 #define HAVE_SYS_SELECT_H 1
 #define HAVE_SYS_TIME_H 1
 #define HAVE_SYS_TIMES_H 1
-#define HAVE_SYS_PARAM_H 1
 #define HAVE_PWD_H 1
 #define HAVE_GRP_H 1
 #define HAVE_UTIME_H 1
 #define HAVE_SYS_RESOURCE_H 1
 #define HAVE_FLOAT_H 1
+#define HAVE_UCONTEXT_H 1
 #define HAVE_LANGINFO_H 1
 #define HAVE_LOCALE_H 1
 #define HAVE_TIME_H 1
 #define HAVE_SYS_SOCKET_H 1
+#define HAVE_SYS_UIO_H 1
 #define HAVE_MALLOC_MALLOC_H 1
+#define HAVE_SYS_ATTR_H 1
+#define HAVE_TYPEOF 1
 #define HAVE_LONG_LONG 1
 #define HAVE_OFF_T 1
 #define SIZEOF_INT 4
@@ -59,6 +62,8 @@
 #define SIZEOF_DOUBLE 8
 #define SIZEOF_TIME_T 8
 #define SIZEOF_CLOCK_T 8
+#define PACKED_STRUCT(x) x __attribute__((packed))
+#define PACKED_STRUCT_UNALIGNED(x) x
 #define PRI_LL_PREFIX "ll"
 #define rb_pid_t pid_t
 #define SIGNEDNESS_OF_PID_T -1
@@ -131,11 +136,13 @@
 #define HAVE_ST_BLOCKS 1
 #define HAVE_STRUCT_STAT_ST_RDEV 1
 #define HAVE_ST_RDEV 1
-#define SIZEOF_STRUCT_STAT_ST_SIZE SIZEOF_LONG
-#define SIZEOF_STRUCT_STAT_ST_BLOCKS SIZEOF_LONG
+#define SIZEOF_STRUCT_STAT_ST_SIZE SIZEOF_OFF_T
+#define SIZEOF_STRUCT_STAT_ST_BLOCKS SIZEOF_OFF_T
+#define SIZEOF_STRUCT_STAT_ST_INO SIZEOF_LONG
 #define HAVE_STRUCT_STAT_ST_ATIMESPEC 1
 #define HAVE_STRUCT_STAT_ST_MTIMESPEC 1
 #define HAVE_STRUCT_STAT_ST_CTIMESPEC 1
+#define HAVE_STRUCT_STAT_ST_BIRTHTIMESPEC 1
 #define HAVE_STRUCT_TIMEVAL 1
 #define SIZEOF_STRUCT_TIMEVAL_TV_SEC SIZEOF_TIME_T
 #define HAVE_STRUCT_TIMESPEC 1
@@ -173,44 +180,53 @@
 #define RETSIGTYPE void
 #define HAVE_ALLOCA_H 1
 #define HAVE_ALLOCA 1
-#define HAVE_DUP2 1
-#define HAVE_MEMMOVE 1
-#define HAVE_STRERROR 1
-#define HAVE_STRCHR 1
-#define HAVE_STRSTR 1
-#define HAVE_CRYPT 1
-#define HAVE_FLOCK 1
-#define HAVE_ISNAN 1
-#define HAVE_FINITE 1
-#define HAVE_ISINF 1
-#define HAVE_HYPOT 1
 #define HAVE_ACOSH 1
-#define HAVE_ERF 1
-#define HAVE_TGAMMA 1
-#define HAVE_LGAMMA_R 1
 #define HAVE_CBRT 1
-#define HAVE_STRLCPY 1
-#define HAVE_STRLCAT 1
+#define HAVE_CRYPT 1
+#define HAVE_DUP2 1
+#define HAVE_ERF 1
 #define HAVE_FFS 1
+#define HAVE_FINITE 1
+#define HAVE_FLOCK 1
+#define HAVE_HYPOT 1
+#define HAVE_ISINF 1
+#define HAVE_ISNAN 1
+#define HAVE_LGAMMA_R 1
+#define HAVE_MEMMOVE 1
+#define HAVE_NEXTAFTER 1
+#define HAVE_STRCHR 1
+#define HAVE_STRERROR 1
+#define HAVE_STRLCAT 1
+#define HAVE_STRLCPY 1
+#define HAVE_STRSTR 1
+#define HAVE_TGAMMA 1
 #define SPT_TYPE SPT_REUSEARGV
 #define HAVE_SIGNBIT 1
-#define HAVE___SYSCALL 1
+#define HAVE_FORK 1
+#define vfork fork
+#define HAVE_WORKING_FORK 1
 #define HAVE__LONGJMP 1
 #define HAVE__SETJMP 1
+#define HAVE_ATAN2L 1
+#define HAVE_ATAN2F 1
 #define HAVE_CHROOT 1
 #define HAVE_CLOCK_GETTIME 1
 #define HAVE_COSH 1
+#define HAVE_DIRFD 1
 #define HAVE_DLOPEN 1
+#define HAVE_DLADDR 1
 #define HAVE_DUP 1
 #define HAVE_ENDGRENT 1
 #define HAVE_FCHMOD 1
 #define HAVE_FCHOWN 1
 #define HAVE_FCNTL 1
+#define HAVE_FGETATTRLIST 1
 #define HAVE_FMOD 1
-#define HAVE_FORK 1
 #define HAVE_FSYNC 1
 #define HAVE_FTRUNCATE 1
+#define HAVE_GETATTRLIST 1
 #define HAVE_GETCWD 1
+#define HAVE_GETGRNAM 1
 #define HAVE_GETGRNAM_R 1
 #define HAVE_GETGROUPS 1
 #define HAVE_GETPGID 1
@@ -234,10 +250,13 @@
 #define HAVE_LSTAT 1
 #define HAVE_MALLOC_SIZE 1
 #define HAVE_MBLEN 1
+#define HAVE_WRITEV 1
+#define HAVE_MEMMEM 1
 #define HAVE_MKTIME 1
 #define HAVE_POLL 1
 #define HAVE_POSIX_MEMALIGN 1
 #define HAVE_PREAD 1
+#define HAVE_QSORT_R 1
 #define HAVE_READLINK 1
 #define HAVE_ROUND 1
 #define HAVE_SEEKDIR 1
@@ -262,7 +281,6 @@
 #define HAVE_SIGPROCMASK 1
 #define HAVE_SINH 1
 #define HAVE_SYMLINK 1
-#define HAVE_SYSCALL 1
 #define HAVE_SYSCONF 1
 #define HAVE_TANH 1
 #define HAVE_TELLDIR 1
@@ -281,7 +299,10 @@
 #define HAVE_BUILTIN___BUILTIN_CLZL 1
 #define HAVE_BUILTIN___BUILTIN_CLZLL 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR 1
+#define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_TYPES_COMPATIBLE_P 1
+#define ATAN2_INF_C99 1
+#define LGAMMA_R_M0_FIX 1
 #define HAVE_CLOCK_GETRES 1
 #define HAVE_STRUCT_TM_TM_ZONE 1
 #define HAVE_TM_ZONE 1
@@ -294,9 +315,6 @@
 #define NEGATIVE_TIME_T 1
 #define POSIX_SIGNAL 1
 #define RSHIFT(x,y) ((x)>>(int)(y))
-#define FILE_COUNT _r
-#define FILE_READPTR _p
-#define SIZEOF_STRUCT_STAT_ST_INO SIZEOF_LONG
 #define HAVE__SC_CLK_TCK 1
 #define STACK_GROW_DIRECTION -1
 #define _REENTRANT 1
@@ -313,6 +331,7 @@
 #define HAVE_PTHREAD_SETNAME_NP 1
 #define HAVE_PTHREAD_ATTR_INIT 1
 #define SET_THREAD_NAME(name) pthread_setname_np(name)
+#define DEFINE_MCONTEXT_PTR(mc, uc) mcontext_t mc = (uc)->uc_mcontext
 #define HAVE_EXECINFO_H 1
 #define HAVE_LIBUNWIND_H 1
 #define HAVE_BACKTRACE 1
